@@ -13,7 +13,7 @@ use IO::Socket::INET;
 use Net::Gnats::PR;
 use Net::Gnats::Response;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 our @CARP_NOT;
 $OUTPUT_AUTOFLUSH = 1;
 
@@ -971,21 +971,33 @@ sub qfmt {
   return;
 }
 
+# Pass in x number query expressions
+# Return array of PR's
+
 sub query {
   my $self = shift;
   my @exprs = @_;
 
   return if not defined $self->reset_server;
   return if not defined $self->qfmt('full');
-  return if not defined $self->expr(@exprs);
+
+  $self->expr(@exprs) if @exprs;
 
   my $r = $self->_do_gnats_cmd('QUER');
-  return $r->raw if $r->code == $CODE_PR_READY;
+
+  return $self->_extract_pr_numbers($r->raw) if $r->code == $CODE_PR_READY;
   return []      if $r->code == $CODE_NO_PRS_MATCHED;
   return         if $r->code == $CODE_INVALID_QUERY_FORMAT;
   return;
 }
 
+sub _extract_pr_numbers {
+  my ($self, $raw) = @_;
+  my @result = map { $_ =~ /^>Number:\s*(\d+)$/ }
+               grep {/^>Number:\s*\d+$/} @{$raw};
+  return @result;
+}
+
 sub _list {
   my ( $self, $listtype, $keynames ) = @_;
 
