@@ -9,8 +9,14 @@ our $VERSION = '0.10';
 sub new {
   my ($class, $param) = @_;
   my $self = bless {}, $class;
-  $self->{raw} = defined $param->{raw} ? $param->{raw} : undef;
-  $self->{code} = defined $param->{code} ? $param->{code} : undef;
+
+  $self->{ raw } = q{};
+  $self->{ code} = -1;
+  my $raw  = defined $param->{raw}  ? $param->{raw}  : q{};
+  my $code = defined $param->{code} ? $param->{code} : -1;
+  $self->raw( $raw );
+  $self->code( $code );
+  $self->{inner_responses} = [];
   return $self;
 }
 
@@ -24,10 +30,28 @@ sub raw {
 # see perldoc for documentation
 sub code {
   my ($self, $value) = @_;
-  if (defined $value) { $self->{code} = $value; }
+  if (defined $value) {
+    if ( $value !~ /\d\d\d/ ) {
+      return $self->{code}
+    }
+    $self->{code} = $value;
+  }
   return $self->{code};
 }
 
+# see perldoc for documentation
+sub inner_responses {
+  my ($self, $value) = @_;
+
+  if (defined $value) {
+    if ( ref $value ne 'Net::Gnats::Response' ) {
+      return $self->{inner_responses}
+    }
+    push @{ $self->{inner_responses} }, $value;
+  }
+  return $self->{inner_responses};
+}
+
 # see perldoc for documentation
 sub as_list {
   my ($self) = @_;
